@@ -76,6 +76,8 @@ from .type_defs import (
     SlateSourceTypeDef,
     UpdateChannelResponseTypeDef,
     UpdateLiveSourceResponseTypeDef,
+    UpdateProgramResponseTypeDef,
+    UpdateProgramScheduleConfigurationTypeDef,
     UpdateSourceLocationResponseTypeDef,
     UpdateVodSourceResponseTypeDef,
 )
@@ -605,6 +607,21 @@ class MediaTailorClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#update_live_source)
         """
 
+    def update_program(
+        self,
+        *,
+        ChannelName: str,
+        ProgramName: str,
+        ScheduleConfiguration: UpdateProgramScheduleConfigurationTypeDef,
+        AdBreaks: Sequence[AdBreakTypeDef] = ...
+    ) -> UpdateProgramResponseTypeDef:
+        """
+        Updates a program within a channel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.update_program)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#update_program)
+        """
+
     def update_source_location(
         self,
         *,
