@@ -49,6 +49,7 @@ __all__ = (
     "BumperTypeDef",
     "CdnConfigurationTypeDef",
     "LogConfigurationForChannelTypeDef",
+    "ClipRangeTypeDef",
     "ConfigureLogsForChannelRequestRequestTypeDef",
     "ResponseMetadataTypeDef",
     "ConfigureLogsForPlaybackConfigurationRequestRequestTypeDef",
@@ -98,6 +99,7 @@ __all__ = (
     "StopChannelRequestRequestTypeDef",
     "TagResourceRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
+    "UpdateProgramTransitionTypeDef",
     "AccessConfigurationTypeDef",
     "ManifestProcessingRulesTypeDef",
     "PrefetchConsumptionTypeDef",
@@ -132,6 +134,7 @@ __all__ = (
     "ScheduleEntryTypeDef",
     "ScheduleConfigurationTypeDef",
     "TimeSignalMessageTypeDef",
+    "UpdateProgramScheduleConfigurationTypeDef",
     "CreateSourceLocationRequestRequestTypeDef",
     "CreateSourceLocationResponseTypeDef",
     "DescribeSourceLocationResponseTypeDef",
@@ -163,6 +166,8 @@ __all__ = (
     "CreateProgramRequestRequestTypeDef",
     "CreateProgramResponseTypeDef",
     "DescribeProgramResponseTypeDef",
+    "UpdateProgramRequestRequestTypeDef",
+    "UpdateProgramResponseTypeDef",
 )
 
 SecretsManagerAccessTokenConfigurationTypeDef = TypedDict(
@@ -257,6 +262,13 @@ LogConfigurationForChannelTypeDef = TypedDict(
     total=False,
 )
 
+ClipRangeTypeDef = TypedDict(
+    "ClipRangeTypeDef",
+    {
+        "EndOffsetMillis": int,
+    },
+)
+
 ConfigureLogsForChannelRequestRequestTypeDef = TypedDict(
     "ConfigureLogsForChannelRequestRequestTypeDef",
     {
@@ -765,6 +777,15 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+UpdateProgramTransitionTypeDef = TypedDict(
+    "UpdateProgramTransitionTypeDef",
+    {
+        "DurationMillis": int,
+        "ScheduledStartTimeMillis": int,
+    },
+    total=False,
+)
+
 AccessConfigurationTypeDef = TypedDict(
     "AccessConfigurationTypeDef",
     {
@@ -1260,12 +1281,26 @@ class ScheduleEntryTypeDef(_RequiredScheduleEntryTypeDef, _OptionalScheduleEntry
     pass
 
 
-ScheduleConfigurationTypeDef = TypedDict(
-    "ScheduleConfigurationTypeDef",
+_RequiredScheduleConfigurationTypeDef = TypedDict(
+    "_RequiredScheduleConfigurationTypeDef",
     {
         "Transition": TransitionTypeDef,
     },
 )
+_OptionalScheduleConfigurationTypeDef = TypedDict(
+    "_OptionalScheduleConfigurationTypeDef",
+    {
+        "ClipRange": ClipRangeTypeDef,
+    },
+    total=False,
+)
+
+
+class ScheduleConfigurationTypeDef(
+    _RequiredScheduleConfigurationTypeDef, _OptionalScheduleConfigurationTypeDef
+):
+    pass
+
 
 TimeSignalMessageTypeDef = TypedDict(
     "TimeSignalMessageTypeDef",
@@ -1275,6 +1310,15 @@ TimeSignalMessageTypeDef = TypedDict(
     total=False,
 )
 
+UpdateProgramScheduleConfigurationTypeDef = TypedDict(
+    "UpdateProgramScheduleConfigurationTypeDef",
+    {
+        "ClipRange": ClipRangeTypeDef,
+        "Transition": UpdateProgramTransitionTypeDef,
+    },
+    total=False,
+)
+
 _RequiredCreateSourceLocationRequestRequestTypeDef = TypedDict(
     "_RequiredCreateSourceLocationRequestRequestTypeDef",
     {
@@ -1820,7 +1864,9 @@ CreateProgramResponseTypeDef = TypedDict(
         "AdBreaks": List[AdBreakTypeDef],
         "Arn": str,
         "ChannelName": str,
+        "ClipRange": ClipRangeTypeDef,
         "CreationTime": datetime,
+        "DurationMillis": int,
         "LiveSourceName": str,
         "ProgramName": str,
         "ScheduledStartTime": datetime,
@@ -1836,7 +1882,50 @@ DescribeProgramResponseTypeDef = TypedDict(
         "AdBreaks": List[AdBreakTypeDef],
         "Arn": str,
         "ChannelName": str,
+        "ClipRange": ClipRangeTypeDef,
         "CreationTime": datetime,
+        "DurationMillis": int,
+        "LiveSourceName": str,
+        "ProgramName": str,
+        "ScheduledStartTime": datetime,
+        "SourceLocationName": str,
+        "VodSourceName": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredUpdateProgramRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateProgramRequestRequestTypeDef",
+    {
+        "ChannelName": str,
+        "ProgramName": str,
+        "ScheduleConfiguration": UpdateProgramScheduleConfigurationTypeDef,
+    },
+)
+_OptionalUpdateProgramRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateProgramRequestRequestTypeDef",
+    {
+        "AdBreaks": Sequence[AdBreakTypeDef],
+    },
+    total=False,
+)
+
+
+class UpdateProgramRequestRequestTypeDef(
+    _RequiredUpdateProgramRequestRequestTypeDef, _OptionalUpdateProgramRequestRequestTypeDef
+):
+    pass
+
+
+UpdateProgramResponseTypeDef = TypedDict(
+    "UpdateProgramResponseTypeDef",
+    {
+        "AdBreaks": List[AdBreakTypeDef],
+        "Arn": str,
+        "ChannelName": str,
+        "ClipRange": ClipRangeTypeDef,
+        "CreationTime": datetime,
+        "DurationMillis": int,
         "LiveSourceName": str,
         "ProgramName": str,
         "ScheduledStartTime": datetime,
